package com.tongran.rocketmq.service;

import java.util.List;
import com.tongran.rocketmq.domain.RmAlarmPushConfig;

/**
 * 告警推送配置Service接口
 * 
 * @author tongran
 * @date 2025-11-11
 */
public interface IRmAlarmPushConfigService 
{
    /**
     * 查询告警推送配置
     * 
     * @param id 告警推送配置主键
     * @return 告警推送配置
     */
    public RmAlarmPushConfig selectRmAlarmPushConfigById(Long id);

    /**
     * 查询告警推送配置列表
     * 
     * @param rmAlarmPushConfig 告警推送配置
     * @return 告警推送配置集合
     */
    public List<RmAlarmPushConfig> selectRmAlarmPushConfigList(RmAlarmPushConfig rmAlarmPushConfig);

    /**
     * 新增告警推送配置
     * 
     * @param rmAlarmPushConfig 告警推送配置
     * @return 结果
     */
    public int insertRmAlarmPushConfig(RmAlarmPushConfig rmAlarmPushConfig);

    /**
     * 修改告警推送配置
     * 
     * @param rmAlarmPushConfig 告警推送配置
     * @return 结果
     */
    public int updateRmAlarmPushConfig(RmAlarmPushConfig rmAlarmPushConfig);

    /**
     * 批量删除告警推送配置
     * 
     * @param ids 需要删除的告警推送配置主键集合
     * @return 结果
     */
    public int deleteRmAlarmPushConfigByIds(Long[] ids);

    /**
     * 删除告警推送配置信息
     * 
     * @param id 告警推送配置主键
     * @return 结果
     */
    public int deleteRmAlarmPushConfigById(Long id);
}
